import { ChakraProvider, ColorModeScript, extendTheme } from '@chakra-ui/react'
import * as theme from 'config/chakra.config'

import { FatalErrorBoundary, RedwoodProvider } from '@redwoodjs/web'

import { DevFatalError } from './pages/fatal-error'
import Routes from './Routes'
import { QueryClient, QueryClientProvider } from 'react-query'

const extendedTheme = extendTheme(theme)

const App = () => {
  const queryClient = new QueryClient()

  return (
    <FatalErrorBoundary page={DevFatalError}>
      <RedwoodProvider titleTemplate="%PageTitle | %AppTitle">
        <ColorModeScript />
        <QueryClientProvider client={queryClient}>
          <ChakraProvider theme={extendedTheme}>
            <Routes />
          </ChakraProvider>
        </QueryClientProvider>
      </RedwoodProvider>
    </FatalErrorBoundary>
  )
}
export default App
